@@ -2,8 +2,9 @@
 # -*- coding: utf-8 -*-
 
 import sys
-from os.path import join
+import urlparse
 import inspect
+from os.path import join
 
 import requests
 from requests.exceptions import HTTPError, TooManyRedirects, Timeout, ConnectionError, InvalidSchema
@@ -103,16 +104,16 @@ class Reviewer(object):
             self.async_get_func(url, handler, method, **kw)
 
     def _get(self, url):
-        if self.proxies:
-            logging.debug('Getting "%s" using proxy "%s"...' % (url, self.proxies.get('http', None)))
-            return requests.get(url, proxies=self.proxies)
+        #if self.proxies:
+            #logging.debug('Getting "%s" using proxy "%s"...' % (url, self.proxies.get('http', None)))
+            #return requests.get(url, proxies=self.proxies)
 
         return requests.get(url)
 
     def _post(self, url, data):
-        if self.proxies:
-            logging.debug('Posting to "%s" using proxy "%s"...' % (url, self.proxies.get('http', None)))
-            return requests.post(url, data=data, proxies=self.proxies)
+        #if self.proxies:
+            #logging.debug('Posting to "%s" using proxy "%s"...' % (url, self.proxies.get('http', None)))
+            #return requests.post(url, data=data, proxies=self.proxies)
 
         return requests.post(url, data=data)
 
@@ -155,46 +156,6 @@ class Reviewer(object):
     def current(self):
         return self._current
 
-    def get_response(self, url):
-        if url in self.responses:
-            return self.responses[url]
-
-        self.responses[url] = {}
-
-        try:
-            response = self._get(url)
-            self.raw_responses[url] = response
-        except Exception:
-            result = {
-                'url': url,
-                'status': 404,
-                'content': '',
-                'html': None
-            }
-        else:
-            result = {
-                'url': url,
-                'status': response.status_code,
-                'content': response.content,
-                'html': None
-            }
-
-            if response.status_code < 399:
-                try:
-                    result['html'] = lxml.html.fromstring(response.text)
-                except (lxml.etree.XMLSyntaxError, lxml.etree.ParserError):
-                    result['html'] = None
-
-                    self.add_violation(
-                        key='invalid.content',
-                        title='Invalid Content',
-                        description='Fail to parse content from %s' % url,
-                        points=1000)
-
-        self.responses[url] = result
-
-        return result
-
     @property
     def current_html(self):
         if not hasattr(self.current, 'html') or self.current.html is None:
@@ -202,20 +163,6 @@ class Reviewer(object):
         else:
             return self.current.html
 
-    def get_status_code(self, url):
-        if not url in self.status_codes:
-            try:
-                response = requests.request(method='GET', url=url, stream=True, timeout=10.0, proxies=self.proxies)
-                response.iter_lines().next()
-                self.raw_responses[url] = response
-                self.status_codes[url] = response.status_code
-            except (TooManyRedirects, Timeout, HTTPError, ConnectionError, InvalidSchema):
-                err = sys.exc_info()[1]
-                logging.warn('ERROR IN %s: %s' % (url, str(err)))
-                self.status_codes[url] = 404
-
-        return self.status_codes[url]
-
     def run_facters(self):
         for facter in self.facters:
             logging.debug('---------- Started running facter %s ---------' % facter.__name__)
@@ -231,17 +178,17 @@ class Reviewer(object):
     def get_url(self, url):
         return join(self.api_url.rstrip('/'), url.lstrip('/'))
 
-    def enqueue(self, *urls):
+    def enqueue(self, urls):
         if not urls:
             return
 
-        if len(urls) == 1:
+        if isinstance(urls, basestring):
             post_url = self.get_url('/page')
             data = dumps({
                 'url': urls[0],
                 'origin_uuid': str(self.page_uuid)
             })
-            error_message = "Could not enqueue page '" + urls[0] + "'! Status Code: %d, Error: %s"
+            error_message = "Could not enqueue page '" + urls + "'! Status Code: %d, Error: %s"
         else:
             post_url = self.get_url('/pages')
             data = {
@@ -287,3 +234,7 @@ class Reviewer(object):
 
     def wait_for_async_requests(self):
         self._wait_for_async_requests(self._wait_timeout)
+
+    def is_root(self):
+        result = urlparse.urlparse(self.page_url)
+        return '{0}://{1}'.format(result.scheme, result.netloc) == self.page_url.rstrip('/')
